# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.contacts_response import ContactsResponse
from .transfer_out_detail_vendor_billing_data import TransferOutDetailVendorBillingData


class TransferOutDetailVendor(UniversalBaseModel):
    """
    Vendor information for an outbound transfer detail.
    """

    vendor_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="VendorNumber"),
        pydantic.Field(alias="VendorNumber", description="The vendor's unique number."),
    ] = None
    name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name1"),
        pydantic.Field(alias="Name1", description="Primary name of the vendor."),
    ] = None
    name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name2"),
        pydantic.Field(alias="Name2", description="Secondary name of the vendor."),
    ] = None
    ein: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EIN"),
        pydantic.Field(alias="EIN", description="Employer Identification Number."),
    ] = None
    phone: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Phone"),
        pydantic.Field(alias="Phone", description="Vendor's phone number."),
    ] = None
    email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Email"),
        pydantic.Field(alias="Email", description="Vendor's email address."),
    ] = None
    remit_email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="RemitEmail"),
        pydantic.Field(alias="RemitEmail", description="Email for remittance notifications."),
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address1"),
        pydantic.Field(alias="Address1", description="Primary address line."),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address2"),
        pydantic.Field(alias="Address2", description="Secondary address line."),
    ] = None
    city: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="City"),
        pydantic.Field(alias="City", description="City of the vendor."),
    ] = None
    state: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="State"),
        pydantic.Field(alias="State", description="State of the vendor."),
    ] = None
    zip: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Zip"),
        pydantic.Field(alias="Zip", description="ZIP code of the vendor."),
    ] = None
    country: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Country"),
        pydantic.Field(alias="Country", description="Country of the vendor."),
    ] = None
    mcc: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Mcc"),
        pydantic.Field(alias="Mcc", description="Merchant Category Code."),
    ] = None
    location_code: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="LocationCode"),
        pydantic.Field(alias="LocationCode", description="Location code for the vendor."),
    ] = None
    contacts: typing_extensions.Annotated[
        typing.Optional[typing.List[ContactsResponse]],
        FieldMetadata(alias="Contacts"),
        pydantic.Field(alias="Contacts", description="List of contacts for the vendor."),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[TransferOutDetailVendorBillingData],
        FieldMetadata(alias="BillingData"),
        pydantic.Field(alias="BillingData", description="Billing data for the vendor."),
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentMethod"),
        pydantic.Field(alias="PaymentMethod", description="Preferred payment method."),
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="VendorStatus"),
        pydantic.Field(alias="VendorStatus", description="Status of the vendor."),
    ] = None
    vendor_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="VendorId"),
        pydantic.Field(alias="VendorId", description="Unique identifier for the vendor."),
    ] = None
    enrollment_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="EnrollmentStatus"),
        pydantic.Field(alias="EnrollmentStatus", description="Enrollment status of the vendor."),
    ] = None
    summary: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Summary"),
        pydantic.Field(alias="Summary", description="Summary information about the vendor."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Legal name of the paypoint."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PaypointId"),
        pydantic.Field(alias="PaypointId", description="ID of the paypoint."),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="DBA name of the paypoint."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Entry name of the paypoint."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ParentOrgName"),
        pydantic.Field(alias="ParentOrgName", description="Name of the parent organization."),
    ] = None
    parent_org_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ParentOrgId"),
        pydantic.Field(alias="ParentOrgId", description="ID of the parent organization."),
    ] = None
    created_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CreatedDate"),
        pydantic.Field(alias="CreatedDate", description="Date the vendor was created."),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="LastUpdated"),
        pydantic.Field(alias="LastUpdated", description="Date the vendor was last updated."),
    ] = None
    remit_address_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitAddress1"),
        pydantic.Field(alias="remitAddress1", description="Primary remittance address line."),
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitAddress2"),
        pydantic.Field(alias="remitAddress2", description="Secondary remittance address line."),
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitCity"),
        pydantic.Field(alias="remitCity", description="Remittance city."),
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitState"),
        pydantic.Field(alias="remitState", description="Remittance state."),
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitZip"),
        pydantic.Field(alias="remitZip", description="Remittance ZIP code."),
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="remitCountry"),
        pydantic.Field(alias="remitCountry", description="Remittance country."),
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="payeeName1"),
        pydantic.Field(alias="payeeName1", description="Primary payee name."),
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="payeeName2"),
        pydantic.Field(alias="payeeName2", description="Secondary payee name."),
    ] = None
    custom_field_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField1"),
        pydantic.Field(alias="customField1", description="Custom field 1."),
    ] = None
    custom_field_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField2"),
        pydantic.Field(alias="customField2", description="Custom field 2."),
    ] = None
    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount", description="Customer vendor account number."),
    ] = None
    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="InternalReferenceId"),
        pydantic.Field(alias="InternalReferenceId", description="Internal reference ID."),
    ] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Any]],
        FieldMetadata(alias="additionalData"),
        pydantic.Field(alias="additionalData", description="Additional data for the vendor."),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID", description="External paypoint ID."),
    ] = None
    stored_methods: typing_extensions.Annotated[
        typing.Optional[typing.List[typing.Any]],
        FieldMetadata(alias="StoredMethods"),
        pydantic.Field(alias="StoredMethods", description="Stored payment methods for the vendor."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.ach_holder_type import AchHolderType
from ...types.ach_sec_code import AchSecCode
from ...types.bin_data import BinData
from ...types.descriptor import Descriptor
from ...types.holdername import Holdername
from ...types.maskedaccount import Maskedaccount
from .get_method_response_response_data_customers_item import GetMethodResponseResponseDataCustomersItem
from .get_method_response_response_data_vendors_item import GetMethodResponseResponseDataVendorsItem


class GetMethodResponseResponseData(UniversalBaseModel):
    aba: typing.Optional[str] = pydantic.Field(default=None)
    """
    Bank routing number
    """

    ach_holder_type: typing_extensions.Annotated[
        typing.Optional[AchHolderType], FieldMetadata(alias="achHolderType"), pydantic.Field(alias="achHolderType")
    ] = None
    ach_sec_code: typing_extensions.Annotated[
        typing.Optional[AchSecCode], FieldMetadata(alias="achSecCode"), pydantic.Field(alias="achSecCode")
    ] = None
    bin: typing.Optional[str] = pydantic.Field(default=None)
    """
    The bank identification number (BIN)
    """

    bin_data: typing_extensions.Annotated[
        typing.Optional[BinData], FieldMetadata(alias="binData"), pydantic.Field(alias="binData")
    ] = None
    card_updated_on: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="cardUpdatedOn"),
        pydantic.Field(alias="cardUpdatedOn", description="Timestamp for when card was last updated"),
    ] = None
    customers: typing.Optional[typing.List[GetMethodResponseResponseDataCustomersItem]] = None
    descriptor: typing.Optional[Descriptor] = None
    exp_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="expDate"),
        pydantic.Field(alias="expDate", description="Expiration date for card in stored method in format MM/YY"),
    ] = None
    holder_name: typing_extensions.Annotated[
        typing.Optional[Holdername],
        FieldMetadata(alias="holderName"),
        pydantic.Field(alias="holderName", description="Account holder name in stored method"),
    ] = None
    id_pmethod: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="idPmethod"),
        pydantic.Field(alias="idPmethod", description="The stored payment method's identifier in Payabli"),
    ] = None
    is_validated_ach: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isValidatedACH"),
        pydantic.Field(alias="isValidatedACH", description="Whether the ACH account has been validated"),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="lastUpdated"),
        pydantic.Field(alias="lastUpdated", description="Timestamp for last update of stored method, in UTC"),
    ] = None
    masked_account: typing_extensions.Annotated[
        typing.Optional[Maskedaccount], FieldMetadata(alias="maskedAccount"), pydantic.Field(alias="maskedAccount")
    ] = None
    method: typing.Optional[str] = pydantic.Field(default=None)
    """
    The saved method's type: `card` or `ach`.
    """

    method_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="methodType"),
        pydantic.Field(alias="methodType", description="The payment method's token type"),
    ] = None
    postal_code: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="postalCode"),
        pydantic.Field(alias="postalCode", description="The payment method postal code"),
    ] = None
    vendors: typing.Optional[typing.List[GetMethodResponseResponseDataVendorsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .bad_request_auth_response_error_v_2 import BadRequestAuthResponseErrorV2
    from .bad_request_capture_response_error_v_2 import BadRequestCaptureResponseErrorV2
    from .bad_request_refund_response_error_v_2 import BadRequestRefundResponseErrorV2
    from .bad_request_void_response_error_v_2 import BadRequestVoidResponseErrorV2
    from .declined_auth_response_error_v_2 import DeclinedAuthResponseErrorV2
    from .declined_capture_response_error_v_2 import DeclinedCaptureResponseErrorV2
    from .declined_refund_response_error_v_2 import DeclinedRefundResponseErrorV2
    from .declined_void_response_error_v_2 import DeclinedVoidResponseErrorV2
    from .internal_server_response_error_v_2 import InternalServerResponseErrorV2
_dynamic_imports: typing.Dict[str, str] = {
    "BadRequestAuthResponseErrorV2": ".bad_request_auth_response_error_v_2",
    "BadRequestCaptureResponseErrorV2": ".bad_request_capture_response_error_v_2",
    "BadRequestRefundResponseErrorV2": ".bad_request_refund_response_error_v_2",
    "BadRequestVoidResponseErrorV2": ".bad_request_void_response_error_v_2",
    "DeclinedAuthResponseErrorV2": ".declined_auth_response_error_v_2",
    "DeclinedCaptureResponseErrorV2": ".declined_capture_response_error_v_2",
    "DeclinedRefundResponseErrorV2": ".declined_refund_response_error_v_2",
    "DeclinedVoidResponseErrorV2": ".declined_void_response_error_v_2",
    "InternalServerResponseErrorV2": ".internal_server_response_error_v_2",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BadRequestAuthResponseErrorV2",
    "BadRequestCaptureResponseErrorV2",
    "BadRequestRefundResponseErrorV2",
    "BadRequestVoidResponseErrorV2",
    "DeclinedAuthResponseErrorV2",
    "DeclinedCaptureResponseErrorV2",
    "DeclinedRefundResponseErrorV2",
    "DeclinedVoidResponseErrorV2",
    "InternalServerResponseErrorV2",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.ach_holder_type import AchHolderType
from ...types.ach_sec_code import AchSecCode
from ...types.batch_number import BatchNumber
from ...types.bill_data import BillData
from ...types.category import Category
from ...types.chargeback_id import ChargebackId
from ...types.created_at import CreatedAt
from ...types.dbaname import Dbaname
from ...types.deposit_date import DepositDate
from ...types.device import Device
from ...types.entrypage_id import EntrypageId
from ...types.entrypointfield import Entrypointfield
from ...types.expected_deposit_date import ExpectedDepositDate
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.fee_amount import FeeAmount
from ...types.legalname import Legalname
from ...types.maskedaccount import Maskedaccount
from ...types.netamountnullable import Netamountnullable
from ...types.operation import Operation
from ...types.order_id import OrderId
from ...types.org_parent_name import OrgParentName
from ...types.orgid import Orgid
from ...types.payor_id import PayorId
from ...types.paypoint_id import PaypointId
from ...types.pending_fee_amount import PendingFeeAmount
from ...types.query_c_fee_transaction import QueryCFeeTransaction
from ...types.query_payment_data import QueryPaymentData
from ...types.query_response_data import QueryResponseData
from ...types.query_transaction_events import QueryTransactionEvents
from ...types.query_transaction_payor_data import QueryTransactionPayorData
from ...types.refund_id import RefundId
from ...types.retrieval_id import RetrievalId
from ...types.returned_id import ReturnedId
from ...types.source import Source
from ...types.split_funding import SplitFunding
from ...types.transaction_time import TransactionTime


class BatchDetailResponseRecord(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from payabli import (
        PaymentCategories,
        PaymentDetail,
        QueryPaymentData,
        QueryResponseData,
        QueryTransactionEvents,
        QueryTransactionPayorData,
        SplitFundingContent,
    )
    from payabli.query_types import BatchDetailResponseRecord

    BatchDetailResponseRecord(
        id=25048,
        method="ach",
        settled_amount=0.5,
        type="credit",
        batch_number="batch-100-20-2024",
        batch_amount=32.0,
        payment_trans_id="245-9e4072eef77e45979ea0e49f680000X",
        payment_trans_status=1,
        schedule_reference=0,
        gateway_trans_id="TRN_XXXXX",
        order_id="",
        trans_method="ach",
        payment_data=QueryPaymentData(
            account_type="Checking",
            holder_name="Lydia Marshall",
            masked_account="1XXXXXX5678",
            payment_details=PaymentDetail(
                categories=[
                    PaymentCategories(
                        amount=1000.0,
                        label="Deposit",
                    )
                ],
                currency="USD",
                service_fee=0.0,
                split_funding=[SplitFundingContent()],
                total_amount=2.0,
            ),
        ),
        net_amount=2.0,
        operation="Sale",
        category="auth",
        source="api",
        status=1,
        transaction_time=datetime.datetime.fromisoformat(
            "2024-11-19 15:58:01+00:00",
        ),
        customer=QueryTransactionPayorData(
            billing_address_1="100 Golden Ridge Drive",
            billing_address_2="STE 100",
            billing_city="Mendota",
            billing_country="US",
            billing_email="lydia@example.com",
            billing_phone="+12345678",
            billing_state="VA",
            billing_zip="20147",
            customer_id=2707,
            customer_number="901102",
            customer_status=1,
            first_name="Lydia",
            last_name="Marshall",
        ),
        settlement_date=datetime.datetime.fromisoformat(
            "2024-11-20 00:00:00+00:00",
        ),
        payment_settlement_status=1,
        batch_status=1,
        deposit_date=datetime.datetime.fromisoformat(
            "2024-11-22 00:00:00+00:00",
        ),
        expected_deposit_date=datetime.datetime.fromisoformat(
            "2024-11-22 00:00:00+00:00",
        ),
        masked_account="1XXXXXX5678",
        created_at=datetime.datetime.fromisoformat(
            "2024-11-19 15:58:01+00:00",
        ),
        paypoint_legalname="Gruzya Adventure Outfitters, LLC",
        response_data=QueryResponseData(
            authcode=" ",
            avsresponse=" ",
            avsresponse_text="",
            cvvresponse=" ",
            cvvresponse_text=" ",
            emv_auth_response_data=" ",
            response="Success",
            response_code="100",
            response_code_text="Transaction was approved.",
            responsetext="CAPTURED",
            result_code="A0000",
            result_code_text="Approved",
            transactionid="TRN_xwCAjQorWAYX1nAhAoHZVfN8iYHbI0",
        ),
        paypoint_dbaname="Gruzya Adventure Outfitters, LLC",
        parent_org_name="Pilgrim Planner",
        parent_org_id=123,
        paypoint_entryname="7f1a3816XX",
        device_id="",
        retrieval_id=0,
        chargeback_id=0,
        ach_holder_type="personal",
        ach_sec_code="PPD",
        connector_name="DefaultConnector",
        entrypage_id=0,
        fee_amount=0.0,
        org_id=123,
        payor_id=2707,
        paypoint_id=123,
        pending_fee_amount=0.0,
        refund_id=0,
        returned_id=0,
        split_funding_instructions=[],
        total_amount=2.0,
        cfee_transactions=[],
        transaction_events=[
            QueryTransactionEvents(
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-19 15:57:40+00:00",
                ),
                trans_event="Created",
            ),
            QueryTransactionEvents(
                event_data={
                    "account_id": "TRA_XXXXX",
                    "account_name": "123456",
                    "action": {
                        "app_id": "XXXXX",
                        "app_name": "PayAbli",
                        "id": "ACT_XXXXX",
                        "result_code": "SUCCESS",
                        "time_created": "2024-11-19T20:58:01.583Z",
                        "type": "AUTHORIZE",
                    },
                    "amount": "200",
                    "batch_id": "",
                    "capture_mode": "AUTO",
                    "channel": "CNP",
                    "country": "US",
                    "currency": "USD",
                    "fees": {"amount": "0", "rate": "0.00", "total_amount": "0"},
                    "id": "TRN_XXXXX",
                    "merchant_amount": "200",
                    "merchant_id": "MER_XXXXX",
                    "merchant_name": "Henriette97",
                    "order": {"reference": ""},
                    "payment_method": {
                        "bank_transfer": {
                            "account_type": "CHECKING",
                            "bank": {"name": ""},
                            "masked_account_number_last4": "XXXX5678",
                        },
                        "entry_mode": "ECOM",
                        "message": "Success",
                        "narrative": "Lydia Marshall",
                        "result": "00",
                    },
                    "reference": "245-XXXXX",
                    "status": "CAPTURED",
                    "time_created": "2024-11-19T20:58:01.583Z",
                    "type": "SALE",
                },
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-19 20:58:01+00:00",
                ),
                trans_event="Approved",
            ),
            QueryTransactionEvents(
                event_time=datetime.datetime.fromisoformat(
                    "2024-11-20 03:05:10+00:00",
                ),
                trans_event="ClosedBatch",
            ),
        ],
        external_paypoint_id="ext-paypoint-123",
        is_hold=0,
    )
    """

    id: typing_extensions.Annotated[int, FieldMetadata(alias="Id"), pydantic.Field(alias="Id")]
    method: typing_extensions.Annotated[str, FieldMetadata(alias="Method"), pydantic.Field(alias="Method")]
    wallet_type: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="WalletType"), pydantic.Field(alias="WalletType")
    ] = None
    settled_amount: typing_extensions.Annotated[
        float, FieldMetadata(alias="SettledAmount"), pydantic.Field(alias="SettledAmount")
    ]
    type: typing_extensions.Annotated[str, FieldMetadata(alias="Type"), pydantic.Field(alias="Type")]
    batch_number: typing_extensions.Annotated[
        BatchNumber, FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ]
    batch_amount: typing_extensions.Annotated[
        float, FieldMetadata(alias="BatchAmount"), pydantic.Field(alias="BatchAmount")
    ]
    payment_trans_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="PaymentTransId"), pydantic.Field(alias="PaymentTransId")
    ]
    payment_trans_status: typing_extensions.Annotated[
        int, FieldMetadata(alias="PaymentTransStatus"), pydantic.Field(alias="PaymentTransStatus")
    ]
    schedule_reference: typing_extensions.Annotated[
        int, FieldMetadata(alias="ScheduleReference"), pydantic.Field(alias="ScheduleReference")
    ]
    gateway_trans_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="GatewayTransId"), pydantic.Field(alias="GatewayTransId")
    ]
    order_id: typing_extensions.Annotated[OrderId, FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")]
    trans_method: typing_extensions.Annotated[
        str, FieldMetadata(alias="TransMethod"), pydantic.Field(alias="TransMethod")
    ]
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ] = None
    net_amount: typing_extensions.Annotated[
        Netamountnullable, FieldMetadata(alias="NetAmount"), pydantic.Field(alias="NetAmount")
    ]
    operation: typing_extensions.Annotated[
        Operation, FieldMetadata(alias="Operation"), pydantic.Field(alias="Operation")
    ]
    category: typing_extensions.Annotated[Category, FieldMetadata(alias="Category"), pydantic.Field(alias="Category")]
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    status: typing_extensions.Annotated[int, FieldMetadata(alias="Status"), pydantic.Field(alias="Status")]
    transaction_time: typing_extensions.Annotated[
        TransactionTime, FieldMetadata(alias="TransactionTime"), pydantic.Field(alias="TransactionTime")
    ]
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorData], FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ] = None
    settlement_date: typing_extensions.Annotated[
        dt.datetime, FieldMetadata(alias="SettlementDate"), pydantic.Field(alias="SettlementDate")
    ]
    payment_settlement_status: typing_extensions.Annotated[
        int, FieldMetadata(alias="PaymentSettlementStatus"), pydantic.Field(alias="PaymentSettlementStatus")
    ]
    batch_status: typing_extensions.Annotated[
        int, FieldMetadata(alias="BatchStatus"), pydantic.Field(alias="BatchStatus")
    ]
    deposit_date: typing_extensions.Annotated[
        DepositDate, FieldMetadata(alias="DepositDate"), pydantic.Field(alias="DepositDate")
    ]
    expected_deposit_date: typing_extensions.Annotated[
        ExpectedDepositDate, FieldMetadata(alias="ExpectedDepositDate"), pydantic.Field(alias="ExpectedDepositDate")
    ]
    masked_account: typing_extensions.Annotated[
        Maskedaccount, FieldMetadata(alias="MaskedAccount"), pydantic.Field(alias="MaskedAccount")
    ]
    created_at: typing_extensions.Annotated[
        CreatedAt, FieldMetadata(alias="CreatedAt"), pydantic.Field(alias="CreatedAt")
    ]
    paypoint_legalname: typing_extensions.Annotated[
        Legalname, FieldMetadata(alias="PaypointLegalname"), pydantic.Field(alias="PaypointLegalname")
    ]
    response_data: typing_extensions.Annotated[
        typing.Optional[QueryResponseData], FieldMetadata(alias="ResponseData"), pydantic.Field(alias="ResponseData")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        Dbaname, FieldMetadata(alias="PaypointDbaname"), pydantic.Field(alias="PaypointDbaname")
    ]
    parent_org_name: typing_extensions.Annotated[
        OrgParentName, FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ]
    parent_org_id: typing_extensions.Annotated[
        int, FieldMetadata(alias="ParentOrgId"), pydantic.Field(alias="ParentOrgId")
    ]
    paypoint_entryname: typing_extensions.Annotated[
        Entrypointfield, FieldMetadata(alias="PaypointEntryname"), pydantic.Field(alias="PaypointEntryname")
    ]
    device_id: typing_extensions.Annotated[
        typing.Optional[Device], FieldMetadata(alias="DeviceId"), pydantic.Field(alias="DeviceId")
    ] = None
    retrieval_id: typing_extensions.Annotated[
        RetrievalId, FieldMetadata(alias="RetrievalId"), pydantic.Field(alias="RetrievalId")
    ]
    chargeback_id: typing_extensions.Annotated[
        ChargebackId, FieldMetadata(alias="ChargebackId"), pydantic.Field(alias="ChargebackId")
    ]
    ach_holder_type: typing_extensions.Annotated[
        AchHolderType, FieldMetadata(alias="AchHolderType"), pydantic.Field(alias="AchHolderType")
    ]
    ach_sec_code: typing_extensions.Annotated[
        AchSecCode, FieldMetadata(alias="AchSecCode"), pydantic.Field(alias="AchSecCode")
    ]
    connector_name: typing_extensions.Annotated[
        str, FieldMetadata(alias="ConnectorName"), pydantic.Field(alias="ConnectorName")
    ]
    entrypage_id: typing_extensions.Annotated[
        EntrypageId, FieldMetadata(alias="EntrypageId"), pydantic.Field(alias="EntrypageId")
    ]
    fee_amount: typing_extensions.Annotated[
        FeeAmount, FieldMetadata(alias="FeeAmount"), pydantic.Field(alias="FeeAmount")
    ]
    org_id: typing_extensions.Annotated[Orgid, FieldMetadata(alias="OrgId"), pydantic.Field(alias="OrgId")]
    payor_id: typing_extensions.Annotated[PayorId, FieldMetadata(alias="PayorId"), pydantic.Field(alias="PayorId")]
    paypoint_id: typing_extensions.Annotated[
        PaypointId, FieldMetadata(alias="PaypointId"), pydantic.Field(alias="PaypointId")
    ]
    pending_fee_amount: typing_extensions.Annotated[
        PendingFeeAmount, FieldMetadata(alias="PendingFeeAmount"), pydantic.Field(alias="PendingFeeAmount")
    ]
    refund_id: typing_extensions.Annotated[RefundId, FieldMetadata(alias="RefundId"), pydantic.Field(alias="RefundId")]
    returned_id: typing_extensions.Annotated[
        ReturnedId, FieldMetadata(alias="ReturnedId"), pydantic.Field(alias="ReturnedId")
    ]
    split_funding_instructions: typing_extensions.Annotated[
        SplitFunding, FieldMetadata(alias="splitFundingInstructions"), pydantic.Field(alias="splitFundingInstructions")
    ]
    total_amount: typing_extensions.Annotated[
        float, FieldMetadata(alias="TotalAmount"), pydantic.Field(alias="TotalAmount")
    ]
    cfee_transactions: typing_extensions.Annotated[
        typing.List[QueryCFeeTransaction],
        FieldMetadata(alias="CfeeTransactions"),
        pydantic.Field(alias="CfeeTransactions"),
    ]
    invoice_data: typing_extensions.Annotated[
        typing.Optional[BillData], FieldMetadata(alias="invoiceData"), pydantic.Field(alias="invoiceData")
    ] = None
    transaction_events: typing_extensions.Annotated[
        typing.List[QueryTransactionEvents],
        FieldMetadata(alias="TransactionEvents"),
        pydantic.Field(alias="TransactionEvents"),
    ]
    external_paypoint_id: typing_extensions.Annotated[
        ExternalPaypointId, FieldMetadata(alias="externalPaypointID"), pydantic.Field(alias="externalPaypointID")
    ]
    is_hold: typing_extensions.Annotated[int, FieldMetadata(alias="isHold"), pydantic.Field(alias="isHold")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .v_2_response_action import V2ResponseAction
from .v_2_response_code import V2ResponseCode
from .v_2_response_explanation import V2ResponseExplanation
from .v_2_response_reason import V2ResponseReason
from .v_2_transaction_details import V2TransactionDetails


class V2TransactionResponseWrapper(UniversalBaseModel):
    """
    Standard response wrapper for v2 Money In transaction endpoints. All v2 transaction endpoints return responses in this format with consistent `code`, `reason`, `explanation`, and `action` fields. The `data` field contains transaction details.
    """

    code: V2ResponseCode
    reason: V2ResponseReason
    explanation: V2ResponseExplanation
    action: V2ResponseAction
    data: V2TransactionDetails
    token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pagination token (equivalent to `pageIdentifier` in v1 APIs). Returns `null` when pagination is not applicable.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutMessageProperties(UniversalBaseModel):
    """
    Properties associated with a transfer message.
    """

    original_transfer_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="originalTransferStatus"),
        pydantic.Field(
            alias="originalTransferStatus", description="The original status of the transfer before the message."
        ),
    ] = None
    current_transfer_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="currentTransferStatus"),
        pydantic.Field(
            alias="currentTransferStatus", description="The current status of the transfer after the message."
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.is_success import IsSuccess
from ...types.page_identifier import PageIdentifier
from ...types.response_text import ResponseText
from ...types.responsecode import Responsecode
from ...types.room_id_not_in_use import RoomIdNotInUse
from .auth_capture_payout_response_data import AuthCapturePayoutResponseData


class AuthCapturePayoutResponse(UniversalBaseModel):
    """
    Examples
    --------
    from payabli.money_out_types import (
        AuthCapturePayoutResponse,
        AuthCapturePayoutResponseData,
    )

    AuthCapturePayoutResponse(
        response_code=1,
        room_id=0,
        is_success=True,
        response_text="Success",
        response_data=AuthCapturePayoutResponseData(
            reference_id="129-219",
            result_code=1,
            result_text="Authorized",
            customer_id=0,
        ),
    )
    """

    response_code: typing_extensions.Annotated[
        Responsecode, FieldMetadata(alias="responseCode"), pydantic.Field(alias="responseCode")
    ]
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier"), pydantic.Field(alias="pageIdentifier")
    ] = None
    room_id: typing_extensions.Annotated[RoomIdNotInUse, FieldMetadata(alias="roomId"), pydantic.Field(alias="roomId")]
    is_success: typing_extensions.Annotated[
        IsSuccess, FieldMetadata(alias="isSuccess"), pydantic.Field(alias="isSuccess")
    ]
    response_text: typing_extensions.Annotated[
        ResponseText, FieldMetadata(alias="responseText"), pydantic.Field(alias="responseText")
    ]
    response_data: typing_extensions.Annotated[
        AuthCapturePayoutResponseData, FieldMetadata(alias="responseData"), pydantic.Field(alias="responseData")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .bin_data import BinData
from .descriptor import Descriptor
from .holdername import Holdername
from .last_modified import LastModified
from .maskedaccount import Maskedaccount


class MethodQueryRecords(UniversalBaseModel):
    bin: typing.Optional[str] = pydantic.Field(default=None)
    """
    The bank identification number (BIN). Null when method is ACH.
    """

    bin_data: typing_extensions.Annotated[
        typing.Optional[BinData], FieldMetadata(alias="binData"), pydantic.Field(alias="binData")
    ] = None
    descriptor: typing.Optional[Descriptor] = None
    exp_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="expDate"),
        pydantic.Field(
            alias="expDate", description="Expiration date associated to the method (only for card) in format MMYY."
        ),
    ] = None
    holder_name: typing_extensions.Annotated[
        typing.Optional[Holdername], FieldMetadata(alias="holderName"), pydantic.Field(alias="holderName")
    ] = None
    id_pmethod: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="idPmethod"),
        pydantic.Field(alias="idPmethod", description="Method internal ID"),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[LastModified],
        FieldMetadata(alias="lastUpdated"),
        pydantic.Field(alias="lastUpdated", description="Date of last update"),
    ] = None
    masked_account: typing_extensions.Annotated[
        typing.Optional[Maskedaccount], FieldMetadata(alias="maskedAccount"), pydantic.Field(alias="maskedAccount")
    ] = None
    method: typing.Optional[str] = pydantic.Field(default=None)
    """
    Type of payment vehicle: **ach** or **card**
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .v_2_bad_request_error_detail import V2BadRequestErrorDetail


class V2BadRequestError(UniversalBaseModel):
    """
    Bad request error response (HTTP 400) returned when request validation fails. Follows RFC 7807 Problem Details format with additional Payabli-specific fields.
    """

    type: str = pydantic.Field()
    """
    A URI reference that identifies the problem type. Points to human-readable documentation for this error type.
    """

    title: str = pydantic.Field()
    """
    Always "Bad Request" for 400 errors.
    """

    status: int = pydantic.Field()
    """
    HTTP status code, always 400 for bad requests.
    """

    detail: str = pydantic.Field()
    """
    Short description of the error.
    """

    instance: str = pydantic.Field()
    """
    Request URL that caused the error.
    """

    code: str = pydantic.Field()
    """
    Payabli's unified response code for validation errors. Starts with 'E'. See [Pay In unified response codes reference](/guides/pay-in-unified-response-codes-reference) for more information.
    """

    errors: typing.Dict[str, typing.List[V2BadRequestErrorDetail]] = pydantic.Field()
    """
    Dictionary of field-specific validation errors. Keys are field paths (e.g., "paymentMethod.cardnumber") and values are arrays of error details.
    """

    token: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pagination token (equivalent to pageIdentifier in v1 APIs). Usually null for errors.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.entrypointfield import Entrypointfield
from ...types.payor_data_request import PayorDataRequest
from ...types.source import Source
from ...types.subdomain import Subdomain
from .request_token_storage_payment_method import RequestTokenStoragePaymentMethod
from .vendor_data_request import VendorDataRequest


class RequestTokenStorage(UniversalBaseModel):
    customer_data: typing_extensions.Annotated[
        typing.Optional[PayorDataRequest],
        FieldMetadata(alias="customerData"),
        pydantic.Field(
            alias="customerData",
            description="Object describing the Customer/Payor owner of payment method. Required for POST requests. Which fields are required depends on the paypoint's custom identifier settings. ",
        ),
    ] = None
    entry_point: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="entryPoint"),
        pydantic.Field(alias="entryPoint", description="Entrypoint identifier. Required for POST requests."),
    ] = None
    fallback_auth: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="fallbackAuth"),
        pydantic.Field(
            alias="fallbackAuth",
            description="When `true`, if tokenization fails, Payabli will attempt an authorization transaction to request a permanent token for the card. If the authorization is successful, the card will be tokenized and the authorization will be voided automatically.",
        ),
    ] = None
    fallback_auth_amount: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="fallbackAuthAmount"),
        pydantic.Field(
            alias="fallbackAuthAmount",
            description="The amount for the `fallbackAuth` transaction. Defaults to one dollar (`100`).",
        ),
    ] = None
    method_description: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="methodDescription"),
        pydantic.Field(alias="methodDescription", description="Custom description for stored payment method."),
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[RequestTokenStoragePaymentMethod],
        FieldMetadata(alias="paymentMethod"),
        pydantic.Field(alias="paymentMethod", description="Information about the payment method for the transaction."),
    ] = None
    vendor_data: typing_extensions.Annotated[
        typing.Optional[VendorDataRequest], FieldMetadata(alias="vendorData"), pydantic.Field(alias="vendorData")
    ] = None
    source: typing.Optional[Source] = pydantic.Field(default=None)
    """
    Custom identifier to indicate the source for the request
    """

    subdomain: typing.Optional[Subdomain] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.external_paypoint_id import ExternalPaypointId
from .v_card_get_response_associated_vendor import VCardGetResponseAssociatedVendor


class VCardGetResponse(UniversalBaseModel):
    vcard_sent: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="vcardSent"),
        pydantic.Field(alias="vcardSent", description="Indicates if the virtual card was sent."),
    ] = None
    card_token: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="cardToken"),
        pydantic.Field(alias="cardToken", description="A unique token identifier for the card."),
    ] = None
    card_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="cardNumber"),
        pydantic.Field(alias="cardNumber", description="The masked number of the card."),
    ] = None
    cvc: typing.Optional[str] = pydantic.Field(default=None)
    """
    Masked Card Verification Code.
    """

    expiration_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="expirationDate"),
        pydantic.Field(alias="expirationDate", description="The expiration date of the card."),
    ] = None
    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    The current status of the card.
    """

    amount: typing.Optional[float] = pydantic.Field(default=None)
    """
    The initial amount loaded on the card.
    """

    current_balance: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="currentBalance"),
        pydantic.Field(alias="currentBalance", description="The current balance available on the card."),
    ] = None
    expense_limit: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="expenseLimit"),
        pydantic.Field(alias="expenseLimit", description="The set limit for expenses."),
    ] = None
    expense_limit_period: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="expenseLimitPeriod"),
        pydantic.Field(alias="expenseLimitPeriod", description="The period for the expense limit."),
    ] = None
    max_number_of_uses: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="maxNumberOfUses"),
        pydantic.Field(alias="maxNumberOfUses", description="Maximum number of uses allowed for the card."),
    ] = None
    current_number_of_uses: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="currentNumberOfUses"),
        pydantic.Field(alias="currentNumberOfUses", description="The current number of times the card has been used."),
    ] = None
    exact_amount: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="exactAmount"),
        pydantic.Field(
            alias="exactAmount", description="Indicates if only the exact amount is allowed for transactions."
        ),
    ] = None
    mcc: typing.Optional[str] = pydantic.Field(default=None)
    """
    Merchant Category Code, if applicable.
    """

    tcc: typing.Optional[str] = pydantic.Field(default=None)
    """
    Transaction Category Code, if applicable.
    """

    misc_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="misc1"),
        pydantic.Field(alias="misc1", description="A miscellaneous field for additional information."),
    ] = None
    misc_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="misc2"),
        pydantic.Field(alias="misc2", description="Another miscellaneous field for extra information."),
    ] = None
    date_created: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dateCreated"),
        pydantic.Field(alias="dateCreated", description="The creation date of the record."),
    ] = None
    date_modified: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dateModified"),
        pydantic.Field(alias="dateModified", description="The last modified date of the record."),
    ] = None
    associated_vendor: typing_extensions.Annotated[
        typing.Optional[VCardGetResponseAssociatedVendor],
        FieldMetadata(alias="associatedVendor"),
        pydantic.Field(alias="associatedVendor", description="Information about the associated vendor."),
    ] = None
    associated_customer: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="associatedCustomer"),
        pydantic.Field(
            alias="associatedCustomer", description="Information about the associated customer, if applicable."
        ),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ParentOrgName"),
        pydantic.Field(alias="ParentOrgName", description="Name of the parent organization."),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The 'Doing Business As' name of the Paypoint."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="The legal name of the Paypoint."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Entry name for the Paypoint, if applicable."),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="paypointId"),
        pydantic.Field(alias="paypointId", description="The unique identifier for the paypoint."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class VCardGetResponseAssociatedVendorSummary(UniversalBaseModel):
    """
    Summary of vendor's billing and transaction status.
    """

    active_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ActiveBills"),
        pydantic.Field(alias="ActiveBills", description="Number of active bills."),
    ] = None
    pending_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PendingBills"),
        pydantic.Field(alias="PendingBills", description="Number of bills pending approval or payment."),
    ] = None
    in_transit_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="InTransitBills"),
        pydantic.Field(alias="InTransitBills", description="Number of bills in transit."),
    ] = None
    paid_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PaidBills"),
        pydantic.Field(alias="PaidBills", description="Number of bills that have been paid."),
    ] = None
    overdue_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="OverdueBills"),
        pydantic.Field(alias="OverdueBills", description="Number of bills that are overdue."),
    ] = None
    approved_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ApprovedBills"),
        pydantic.Field(alias="ApprovedBills", description="Number of bills that have been approved."),
    ] = None
    disapproved_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="DisapprovedBills"),
        pydantic.Field(alias="DisapprovedBills", description="Number of bills that have been disapproved."),
    ] = None
    total_bills: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="TotalBills"),
        pydantic.Field(alias="TotalBills", description="Total number of bills."),
    ] = None
    active_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="ActiveBillsAmount"),
        pydantic.Field(alias="ActiveBillsAmount", description="Total amount of active bills."),
    ] = None
    pending_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="PendingBillsAmount"),
        pydantic.Field(alias="PendingBillsAmount", description="Total amount of pending bills."),
    ] = None
    in_transit_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="InTransitBillsAmount"),
        pydantic.Field(alias="InTransitBillsAmount", description="Total amount of bills in transit."),
    ] = None
    paid_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="PaidBillsAmount"),
        pydantic.Field(alias="PaidBillsAmount", description="Total amount of paid bills."),
    ] = None
    overdue_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="OverdueBillsAmount"),
        pydantic.Field(alias="OverdueBillsAmount", description="Total amount of overdue bills."),
    ] = None
    approved_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="ApprovedBillsAmount"),
        pydantic.Field(alias="ApprovedBillsAmount", description="Total amount of approved bills."),
    ] = None
    disapproved_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="DisapprovedBillsAmount"),
        pydantic.Field(alias="DisapprovedBillsAmount", description="Total amount of rejected bills."),
    ] = None
    total_bills_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="TotalBillsAmount"),
        pydantic.Field(alias="TotalBillsAmount", description="Total amount of all bills."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .bill_data import BillData
from .created_at import CreatedAt
from .datetime_nullable import DatetimeNullable
from .dbaname import Dbaname
from .entrypage_id import EntrypageId
from .entrypointfield import Entrypointfield
from .external_paypoint_id import ExternalPaypointId
from .general_events import GeneralEvents
from .last_modified import LastModified
from .legalname import Legalname
from .netamountnullable import Netamountnullable
from .org_parent_name import OrgParentName
from .paypoint_id import PaypointId
from .query_payment_data import QueryPaymentData
from .query_transaction_payor_data import QueryTransactionPayorData
from .source import Source


class SubscriptionQueryRecords(UniversalBaseModel):
    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt],
        FieldMetadata(alias="CreatedAt"),
        pydantic.Field(alias="CreatedAt", description="Timestamp of when the subscription ws created, in UTC."),
    ] = None
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorData], FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ] = None
    end_date: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="EndDate"),
        pydantic.Field(alias="EndDate", description="The subscription's end date."),
    ] = None
    entrypage_id: typing_extensions.Annotated[
        typing.Optional[EntrypageId], FieldMetadata(alias="EntrypageId"), pydantic.Field(alias="EntrypageId")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="ExternalPaypointID"),
        pydantic.Field(alias="ExternalPaypointID"),
    ] = None
    fee_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="FeeAmount"),
        pydantic.Field(alias="FeeAmount", description="Fee applied to the subscription."),
    ] = None
    frequency: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Frequency"),
        pydantic.Field(alias="Frequency", description="The subscription's frequency."),
    ] = None
    id_sub: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="IdSub"),
        pydantic.Field(alias="IdSub", description="The subscription's ID."),
    ] = None
    invoice_data: typing_extensions.Annotated[
        typing.Optional[BillData], FieldMetadata(alias="InvoiceData"), pydantic.Field(alias="InvoiceData")
    ] = None
    last_run: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="LastRun"),
        pydantic.Field(alias="LastRun", description="The last time the subscription was processed."),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[LastModified],
        FieldMetadata(alias="LastUpdated"),
        pydantic.Field(alias="LastUpdated", description="The last date and time the subscription was updated."),
    ] = None
    left_cycles: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="LeftCycles"),
        pydantic.Field(alias="LeftCycles", description="The number of cycles the subscription has left."),
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="The subscription's payment method."),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[Netamountnullable],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="The subscription amount, minus any fees."),
    ] = None
    next_date: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="NextDate"),
        pydantic.Field(alias="NextDate", description="The next date the subscription will be processed."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The paypoint's DBA name."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="The paypoint's entryname."),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[PaypointId], FieldMetadata(alias="PaypointId"), pydantic.Field(alias="PaypointId")
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="The paypoint's legal name."),
    ] = None
    plan_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="PlanId"),
        pydantic.Field(alias="PlanId", description="Payment plan ID."),
    ] = None
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    start_date: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="StartDate"),
        pydantic.Field(alias="StartDate", description="The subscription start date."),
    ] = None
    sub_events: typing_extensions.Annotated[
        typing.Optional[typing.List[GeneralEvents]],
        FieldMetadata(alias="SubEvents"),
        pydantic.Field(alias="SubEvents", description="Events associated with the subscription."),
    ] = None
    sub_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="SubStatus"),
        pydantic.Field(alias="SubStatus", description="The subscription's status.\n- 0: Paused\n- 1: Active"),
    ] = None
    total_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="TotalAmount"),
        pydantic.Field(alias="TotalAmount", description="The subscription amount, including any fees."),
    ] = None
    total_cycles: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="TotalCycles"),
        pydantic.Field(alias="TotalCycles", description="The total number of cycles the subscription is set to run."),
    ] = None
    until_cancelled: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="UntilCancelled"),
        pydantic.Field(
            alias="UntilCancelled",
            description="When `true`, the subscription has no explicit end date and will run until canceled.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .dbaname import Dbaname
from .entrypointfield import Entrypointfield
from .legalname import Legalname
from .line_item import LineItem
from .org_parent_name import OrgParentName


class QueryResponseItemsRecordsItem(UniversalBaseModel):
    line_item: typing_extensions.Annotated[
        typing.Optional[LineItem], FieldMetadata(alias="LineItem"), pydantic.Field(alias="LineItem")
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The paypoint's DBA name."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="The paypoint's entry name (entrypoint)."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="the Paypoint's legal name."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .payment_categories import PaymentCategories
from .split_funding import SplitFunding


class PaymentDetail(UniversalBaseModel):
    """
    Details about the payment.
    """

    categories: typing.Optional[typing.List[PaymentCategories]] = pydantic.Field(default=None)
    """
    Array of payment categories/line items describing the amount to be paid.
    **Note**: These categories are for information only and aren't validated against the total amount provided.
    """

    check_image: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Any]],
        FieldMetadata(alias="checkImage"),
        pydantic.Field(alias="checkImage", description="Object containing image of paper check."),
    ] = None
    check_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="checkNumber"),
        pydantic.Field(
            alias="checkNumber",
            description="A check number to be used in the ach transaction. **Required** for payment method = 'check'.",
        ),
    ] = None
    currency: typing.Optional[str] = pydantic.Field(default=None)
    """
    The currency for the transaction, `USD` or `CAD`. If your paypoint is configured for CAD, you must send the `CAD` value in this field, otherwise it defaults to USD, which will cause the transaction to fail.
    """

    service_fee: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="serviceFee"),
        pydantic.Field(
            alias="serviceFee",
            description="Service fee to be deducted from the total amount. This amount must be a number, percentages aren't accepted. If you are using a percentage-based fee schedule, you must calculate the value manually.",
        ),
    ] = None
    split_funding: typing_extensions.Annotated[
        typing.Optional[SplitFunding],
        FieldMetadata(alias="splitFunding"),
        pydantic.Field(
            alias="splitFunding",
            description="Split funding instructions for the transaction. See [Split a Transaction](/developers/developer-guides/money-in-split-funding) for more.",
        ),
    ] = None
    check_unique_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="checkUniqueId"),
        pydantic.Field(
            alias="checkUniqueId",
            description="Unique identifier for a processed check image. Required for RDC (Remote Deposit Capture) transactions where `achCode` is `BOC`. Use the `id` value from the [check processing](/developers/api-reference/checkcapture/process-a-check-image) response.",
        ),
    ] = None
    total_amount: typing_extensions.Annotated[
        float,
        FieldMetadata(alias="totalAmount"),
        pydantic.Field(
            alias="totalAmount",
            description='Total amount to be charged. If a service fee is sent, then this amount should include the service fee."',
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .email import Email


class ContactsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from payabli import ContactsResponse

    ContactsResponse(
        contact_email="eric@martinezcoatings.com",
        contact_name="Eric Martinez",
        contact_phone="5555555555",
        contact_title="Owner",
    )
    """

    contact_email: typing_extensions.Annotated[
        typing.Optional[Email],
        FieldMetadata(alias="ContactEmail"),
        pydantic.Field(alias="ContactEmail", description="Contact email address."),
    ] = None
    contact_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ContactName"),
        pydantic.Field(alias="ContactName", description="Contact name."),
    ] = None
    contact_phone: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ContactPhone"),
        pydantic.Field(alias="ContactPhone", description="Contact phone number."),
    ] = None
    contact_title: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ContactTitle"),
        pydantic.Field(alias="ContactTitle", description="Contact title."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.is_enabled import IsEnabled


class AddPaymentMethodDomainRequestApplePay(UniversalBaseModel):
    """
    Apple Pay configuration information.
    """

    is_enabled: typing_extensions.Annotated[
        typing.Optional[IsEnabled], FieldMetadata(alias="isEnabled"), pydantic.Field(alias="isEnabled")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.accounttype import Accounttype
from ...types.created_at import CreatedAt
from ...types.dbaname import Dbaname
from ...types.entrypointfield import Entrypointfield
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.legalname import Legalname
from ...types.netamountnullable import Netamountnullable
from ...types.order_id import OrderId
from ...types.org_parent_name import OrgParentName
from ...types.page_identifier import PageIdentifier
from ...types.query_payment_data import QueryPaymentData
from ...types.query_transaction_payor_data import QueryTransactionPayorData
from ...types.replyby import Replyby
from ...types.transaction_query_records import TransactionQueryRecords
from ...types.transaction_time import TransactionTime
from .charge_back_response import ChargeBackResponse
from .chargeback_message import ChargebackMessage


class ChargebackQueryRecords(UniversalBaseModel):
    id: typing_extensions.Annotated[
        int, FieldMetadata(alias="Id"), pydantic.Field(alias="Id", description="Identifier of chargeback or return.")
    ]
    chargeback_date: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="ChargebackDate"),
        pydantic.Field(alias="ChargebackDate", description="Date of chargeback in format YYYY-MM-DD or MM/DD/YYYY."),
    ]
    case_number: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="CaseNumber"),
        pydantic.Field(alias="CaseNumber", description="Number of case assigned to the chargeback."),
    ]
    reason_code: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="ReasonCode"),
        pydantic.Field(
            alias="ReasonCode", description="R code for returned ACH or custom code identifying the reason."
        ),
    ]
    reason: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="Reason"),
        pydantic.Field(alias="Reason", description="Text describing the chargeback or ACH return reason."),
    ]
    reference_number: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="ReferenceNumber"),
        pydantic.Field(alias="ReferenceNumber", description="Processor reference number to the chargeback."),
    ]
    last_four: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="LastFour"),
        pydantic.Field(
            alias="LastFour", description="Last 4 digits of card or bank account involved in chargeback or return."
        ),
    ]
    account_type: typing_extensions.Annotated[
        Accounttype, FieldMetadata(alias="AccountType"), pydantic.Field(alias="AccountType")
    ]
    status: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="Status"),
        pydantic.Field(
            alias="Status",
            description="Status for chargeback or ACH return\n\n- 0: Open (chargebacks only)\n- 1: Pending (chargebacks only)\n- 2: Closed-Won (chargebacks only)\n- 3: Closed-Lost (chargebacks only)\n- 4: ACH Return (ACH only)\n- 5: ACH Dispute, Not Authorized (ACH only)",
        ),
    ]
    method: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="Type of payment vehicle: **ach** or **card**."),
    ]
    created_at: typing_extensions.Annotated[
        CreatedAt,
        FieldMetadata(alias="CreatedAt"),
        pydantic.Field(alias="CreatedAt", description="Timestamp when the register was created, in UTC."),
    ]
    reply_by: typing_extensions.Annotated[Replyby, FieldMetadata(alias="ReplyBy"), pydantic.Field(alias="ReplyBy")]
    payment_trans_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="PaymentTransId"),
        pydantic.Field(alias="PaymentTransId", description="ReferenceId of the transaction in Payabli."),
    ]
    schedule_reference: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ScheduleReference"),
        pydantic.Field(
            alias="ScheduleReference", description="Reference to the subscription originating the transaction."
        ),
    ] = None
    order_id: typing_extensions.Annotated[OrderId, FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")]
    net_amount: typing_extensions.Annotated[
        Netamountnullable,
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount in chargeback or ACH return."),
    ]
    transaction_time: typing_extensions.Annotated[
        TransactionTime, FieldMetadata(alias="TransactionTime"), pydantic.Field(alias="TransactionTime")
    ]
    customer: typing_extensions.Annotated[
        QueryTransactionPayorData, FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ]
    payment_data: typing_extensions.Annotated[
        QueryPaymentData, FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ]
    paypoint_legalname: typing_extensions.Annotated[
        Legalname,
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="The paypoint's legal name."),
    ]
    paypoint_dbaname: typing_extensions.Annotated[
        Dbaname,
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The paypoint's DBA name."),
    ]
    parent_org_name: typing_extensions.Annotated[
        OrgParentName, FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ]
    parent_org_id: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="ParentOrgId"),
        pydantic.Field(alias="ParentOrgId", description="The ID of the parent organization."),
    ]
    paypoint_entryname: typing_extensions.Annotated[
        Entrypointfield,
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="The paypoint's entryname."),
    ]
    responses: typing_extensions.Annotated[
        typing.List[ChargeBackResponse],
        FieldMetadata(alias="Responses"),
        pydantic.Field(alias="Responses", description="Chargeback response records."),
    ]
    transaction: typing_extensions.Annotated[
        TransactionQueryRecords, FieldMetadata(alias="Transaction"), pydantic.Field(alias="Transaction")
    ]
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    pageidentifier: typing.Optional[PageIdentifier] = None
    messages: typing.List[ChargebackMessage] = pydantic.Field()
    """
    Messages related to the chargeback.
    """

    service_group: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="ServiceGroup"),
        pydantic.Field(alias="ServiceGroup", description="Service group classification."),
    ]
    dispute_type: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="DisputeType"),
        pydantic.Field(alias="DisputeType", description="Type of dispute classification."),
    ]
    processor_name: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="ProcessorName"),
        pydantic.Field(alias="ProcessorName", description="Name of the payment processor."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .created_at import CreatedAt
from .job_id import JobId
from .job_status import JobStatus
from .last_modified import LastModified


class CascadeJobDetails(UniversalBaseModel):
    """
    Details about the cascade process.
    """

    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt], FieldMetadata(alias="createdAt"), pydantic.Field(alias="createdAt")
    ] = None
    job_error_message: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="jobErrorMessage"),
        pydantic.Field(alias="jobErrorMessage", description="Error message for a failed cascade process."),
    ] = None
    job_id: typing_extensions.Annotated[
        typing.Optional[JobId], FieldMetadata(alias="jobId"), pydantic.Field(alias="jobId")
    ] = None
    job_status: typing_extensions.Annotated[
        typing.Optional[JobStatus], FieldMetadata(alias="jobStatus"), pydantic.Field(alias="jobStatus")
    ] = None
    updated_at: typing_extensions.Annotated[
        typing.Optional[LastModified], FieldMetadata(alias="updatedAt"), pydantic.Field(alias="updatedAt")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutDetailPaymentData(UniversalBaseModel):
    """
    Payment data for an outbound transfer detail.
    """

    masked_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="MaskedAccount"),
        pydantic.Field(alias="MaskedAccount", description="Masked account number."),
    ] = None
    account_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="AccountType"),
        pydantic.Field(alias="AccountType", description="Type of account."),
    ] = None
    account_exp: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="AccountExp"),
        pydantic.Field(alias="AccountExp", description="Account expiration date."),
    ] = None
    account_zip: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="AccountZip"),
        pydantic.Field(alias="AccountZip", description="ZIP code associated with the account."),
    ] = None
    holder_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="HolderName"),
        pydantic.Field(alias="HolderName", description="Name of the account holder."),
    ] = None
    stored_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="StoredId"),
        pydantic.Field(alias="StoredId", description="ID of the stored payment method."),
    ] = None
    initiator: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Initiator"),
        pydantic.Field(alias="Initiator", description="Initiator of the payment."),
    ] = None
    stored_method_usage_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="StoredMethodUsageType"),
        pydantic.Field(alias="StoredMethodUsageType", description="Usage type for stored method."),
    ] = None
    sequence: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Sequence"),
        pydantic.Field(alias="Sequence", description="Sequence number."),
    ] = None
    order_description: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="orderDescription"),
        pydantic.Field(alias="orderDescription", description="Description of the order."),
    ] = None
    cloud_signature_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="cloudSignatureData"),
        pydantic.Field(alias="cloudSignatureData", description="Cloud signature data."),
    ] = None
    cloud_signature_format: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="cloudSignatureFormat"),
        pydantic.Field(alias="cloudSignatureFormat", description="Format of cloud signature."),
    ] = None
    payment_details: typing_extensions.Annotated[
        typing.Optional[typing.Any],
        FieldMetadata(alias="paymentDetails"),
        pydantic.Field(alias="paymentDetails", description="Additional payment details."),
    ] = None
    payor_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="payorData"),
        pydantic.Field(alias="payorData", description="Data about the payor."),
    ] = None
    account_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="accountId"),
        pydantic.Field(alias="accountId", description="Account ID."),
    ] = None
    bank_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="bankAccount"),
        pydantic.Field(alias="bankAccount", description="Bank account information."),
    ] = None
    gateway_connector: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="gatewayConnector"),
        pydantic.Field(alias="gatewayConnector", description="Gateway connector used."),
    ] = None
    bin_data: typing_extensions.Annotated[
        typing.Optional[typing.Any],
        FieldMetadata(alias="binData"),
        pydantic.Field(alias="binData", description="BIN data for the card."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .transaction_query_records import TransactionQueryRecords


class CustomerSummaryRecord(UniversalBaseModel):
    numberof_transactions: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="numberofTransactions"),
        pydantic.Field(alias="numberofTransactions", description="Number total of transactions or payments"),
    ] = None
    recent_transactions: typing_extensions.Annotated[
        typing.Optional[typing.List[TransactionQueryRecords]],
        FieldMetadata(alias="recentTransactions"),
        pydantic.Field(
            alias="recentTransactions", description="List of more recent 5 transactions belonging to the customer"
        ),
    ] = None
    total_amount_transactions: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="totalAmountTransactions"),
        pydantic.Field(alias="totalAmountTransactions", description="Total amount in transactions"),
    ] = None
    total_net_amount_transactions: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="totalNetAmountTransactions"),
        pydantic.Field(alias="totalNetAmountTransactions", description="Total net amount in transactions"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .is_success import IsSuccess
from .page_identifier import PageIdentifier
from .payabli_api_response_notifications_response_data import PayabliApiResponseNotificationsResponseData
from .response_text import ResponseText
from .responsecode import Responsecode


class PayabliApiResponseNotifications(UniversalBaseModel):
    is_success: typing_extensions.Annotated[
        typing.Optional[IsSuccess],
        FieldMetadata(alias="isSuccess"),
        pydantic.Field(
            alias="isSuccess",
            description="\nIf `isSuccess` = true, `responseData` contains the notification identifier.\n\nIf `isSuccess` = false, `responseData` contains the reason for the error.",
        ),
    ] = None
    page_identifier: typing_extensions.Annotated[
        typing.Optional[PageIdentifier], FieldMetadata(alias="pageIdentifier"), pydantic.Field(alias="pageIdentifier")
    ] = None
    response_code: typing_extensions.Annotated[
        typing.Optional[Responsecode], FieldMetadata(alias="responseCode"), pydantic.Field(alias="responseCode")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[PayabliApiResponseNotificationsResponseData],
        FieldMetadata(alias="responseData"),
        pydantic.Field(
            alias="responseData",
            description="When the request was successful, this contains the notification ID, or `nID` used to manage the notification.",
        ),
    ] = None
    response_text: typing_extensions.Annotated[
        ResponseText, FieldMetadata(alias="responseText"), pydantic.Field(alias="responseText")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutSummary(UniversalBaseModel):
    """
    Summary information for outbound transfer queries.
    """

    total_pages: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalPages"),
        pydantic.Field(alias="totalPages", description="Number of pages in the response."),
    ] = None
    total_records: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="totalRecords"),
        pydantic.Field(alias="totalRecords", description="Number of records in the response."),
    ] = None
    page_size: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="pageSize"),
        pydantic.Field(alias="pageSize", description="Number of records per page."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .entry import Entry
from .google_wallet_data import GoogleWalletData
from .is_enabled import IsEnabled


class GooglePayPaypointRegistrationData(UniversalBaseModel):
    entry: typing.Optional[Entry] = None
    is_enabled: typing_extensions.Annotated[
        typing.Optional[IsEnabled], FieldMetadata(alias="isEnabled"), pydantic.Field(alias="isEnabled")
    ] = None
    wallet_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="walletType"),
        pydantic.Field(
            alias="walletType", description="The wallet type. In this context it will always be `googlePay`."
        ),
    ] = None
    wallet_data: typing_extensions.Annotated[
        typing.Optional[GoogleWalletData], FieldMetadata(alias="walletData"), pydantic.Field(alias="walletData")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .created_at import CreatedAt
from .dbaname import Dbaname
from .entrypointfield import Entrypointfield
from .external_paypoint_id import ExternalPaypointId
from .legalname import Legalname
from .order_id import OrderId
from .org_parent_name import OrgParentName
from .page_identifier import PageIdentifier
from .query_payment_data import QueryPaymentData
from .query_transaction_payor_data import QueryTransactionPayorData
from .replyby import Replyby
from .transaction_query_records import TransactionQueryRecords
from .transaction_time import TransactionTime


class QueryChargebacksResponseRecordsItem(UniversalBaseModel):
    account_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="AccountType"),
        pydantic.Field(alias="AccountType", description="Type of account."),
    ] = None
    case_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CaseNumber"),
        pydantic.Field(alias="CaseNumber", description="Case number of the chargeback."),
    ] = None
    chargeback_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="ChargebackDate"),
        pydantic.Field(alias="ChargebackDate", description="Date of the chargeback."),
    ] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt], FieldMetadata(alias="CreatedAt"), pydantic.Field(alias="CreatedAt")
    ] = None
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorData], FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="Id"),
        pydantic.Field(alias="Id", description="Unique identifier of the record."),
    ] = None
    last_four: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="LastFour"),
        pydantic.Field(alias="LastFour", description="Last four digits of the account number."),
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="Method of payment."),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount after deductions."),
    ] = None
    order_id: typing_extensions.Annotated[
        typing.Optional[OrderId], FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")
    ] = None
    pageidentifier: typing.Optional[PageIdentifier] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData],
        FieldMetadata(alias="PaymentData"),
        pydantic.Field(alias="PaymentData", description="Payment data associated with the transaction."),
    ] = None
    payment_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentTransId"),
        pydantic.Field(alias="PaymentTransId", description="Transaction ID for the payment."),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="The 'Doing Business As' (DBA) name of the paypoint."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[Entrypointfield],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Entryname for the paypoint."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Legal name of the paypoint."),
    ] = None
    reason: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Reason"),
        pydantic.Field(alias="Reason", description="Description of the reason for chargeback."),
    ] = None
    reason_code: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ReasonCode"),
        pydantic.Field(alias="ReasonCode", description="Code representing the reason for chargeback."),
    ] = None
    reference_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ReferenceNumber"),
        pydantic.Field(alias="ReferenceNumber", description="Reference number for the transaction."),
    ] = None
    reply_by: typing_extensions.Annotated[
        typing.Optional[Replyby], FieldMetadata(alias="ReplyBy"), pydantic.Field(alias="ReplyBy")
    ] = None
    responses: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Responses"),
        pydantic.Field(alias="Responses", description="Responses related to the transaction."),
    ] = None
    schedule_reference: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ScheduleReference"),
        pydantic.Field(alias="ScheduleReference", description="Reference for any scheduled transactions."),
    ] = None
    status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="Status"),
        pydantic.Field(alias="Status", description="Status of the transaction."),
    ] = None
    transaction: typing_extensions.Annotated[
        typing.Optional[TransactionQueryRecords],
        FieldMetadata(alias="Transaction"),
        pydantic.Field(alias="Transaction"),
    ] = None
    transaction_time: typing_extensions.Annotated[
        typing.Optional[TransactionTime],
        FieldMetadata(alias="TransactionTime"),
        pydantic.Field(alias="TransactionTime"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ApplePayMetadata(UniversalBaseModel):
    """
    This metadata appears only when the domain verification check fails. It gives more information about why the check failed.
    """

    is_file_available: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isFileAvailable"),
        pydantic.Field(
            alias="isFileAvailable",
            description="When `true`, indicates whether the domain verification file is available at the expected path. When `false`, Payabli was unable to find the file at the expected path. If the file is missing, make sure it's hosted at the correct path: `/.well-known/apple-developer-merchantid-domain-association`",
        ),
    ] = None
    is_file_content_valid: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isFileContentValid"),
        pydantic.Field(
            alias="isFileContentValid",
            description="Indicates whether the domain verification file content is valid. If the file is invalid, try downloading it and hosting it again.",
        ),
    ] = None
    redirect_domain_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="redirectDomainName"),
        pydantic.Field(
            alias="redirectDomainName", description="The domain name if the domain verification URL returns a redirect."
        ),
    ] = None
    redirect_url: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="redirectUrl"),
        pydantic.Field(
            alias="redirectUrl",
            description="If the domain verification URL is redirected, this is the URL it's redirected to. \nFor example, www.partner.com could redirect to www.partners-new-home-page.com. In this case, you should add www.partners-new-home-page.com as a domain instead of www.partner.com.",
        ),
    ] = None
    status_code: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="statusCode"),
        pydantic.Field(alias="statusCode", description="The status code return by the domain verification URL."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutDetailEvent(UniversalBaseModel):
    """
    Event data for an outbound transfer detail.
    """

    trans_event: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="TransEvent"),
        pydantic.Field(alias="TransEvent", description="Description of the transaction event."),
    ] = None
    event_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EventData"),
        pydantic.Field(alias="EventData", description="Additional event data."),
    ] = None
    event_time: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EventTime"),
        pydantic.Field(alias="EventTime", description="Time the event occurred."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .web_header_parameter import WebHeaderParameter


class NotificationRequest(UniversalBaseModel):
    notification_url: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="notificationUrl"),
        pydantic.Field(alias="notificationUrl", description="Complete HTTP URL receiving the notification"),
    ]
    web_header_parameters: typing_extensions.Annotated[
        typing.Optional[typing.List[WebHeaderParameter]],
        FieldMetadata(alias="webHeaderParameters"),
        pydantic.Field(
            alias="webHeaderParameters",
            description="A dictionary of key-value pairs to be inserted in the header when the notification request is submitted",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.dbaname import Dbaname
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.legalname import Legalname
from ...types.location_code import LocationCode
from ...types.org_parent_name import OrgParentName
from ...types.remitaddress_1 import Remitaddress1
from ...types.remitaddress_2 import Remitaddress2
from ...types.remitcity import Remitcity
from ...types.remitcountry import Remitcountry
from ...types.remitstate import Remitstate
from ...types.remitzip import Remitzip
from .v_card_get_response_associated_vendor_billing_data import VCardGetResponseAssociatedVendorBillingData
from .v_card_get_response_associated_vendor_summary import VCardGetResponseAssociatedVendorSummary
from .v_card_get_response_contact import VCardGetResponseContact


class VCardGetResponseAssociatedVendor(UniversalBaseModel):
    """
    Information about the associated vendor.
    """

    vendor_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="VendorNumber"),
        pydantic.Field(alias="VendorNumber", description="Unique code identifying the vendor."),
    ] = None
    name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name1"),
        pydantic.Field(alias="Name1", description="The primary name associated with the vendor."),
    ] = None
    name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Name2"),
        pydantic.Field(alias="Name2", description="Additional name information for the vendor."),
    ] = None
    ein: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EIN"),
        pydantic.Field(alias="EIN", description="Employer Identification Number of the vendor."),
    ] = None
    phone: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Phone"),
        pydantic.Field(alias="Phone", description="Contact phone number of the vendor."),
    ] = None
    email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Email"),
        pydantic.Field(alias="Email", description="Contact email address of the vendor."),
    ] = None
    remit_email: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="RemitEmail"),
        pydantic.Field(alias="RemitEmail", description="Email address for remittance."),
    ] = None
    address_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address1"),
        pydantic.Field(alias="Address1", description="Primary address line of the vendor."),
    ] = None
    address_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Address2"),
        pydantic.Field(alias="Address2", description="Secondary address line of the vendor."),
    ] = None
    city: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="City"),
        pydantic.Field(alias="City", description="City where the vendor is located."),
    ] = None
    state: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="State"),
        pydantic.Field(alias="State", description="State where the vendor is located."),
    ] = None
    zip: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Zip"),
        pydantic.Field(alias="Zip", description="ZIP code for the vendor's location."),
    ] = None
    country: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Country"),
        pydantic.Field(alias="Country", description="Country where the vendor is located."),
    ] = None
    mcc: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Mcc"),
        pydantic.Field(alias="Mcc", description="Merchant Category Code for the vendor."),
    ] = None
    location_code: typing_extensions.Annotated[
        typing.Optional[LocationCode], FieldMetadata(alias="LocationCode"), pydantic.Field(alias="LocationCode")
    ] = None
    contacts: typing_extensions.Annotated[
        typing.Optional[typing.List[VCardGetResponseContact]],
        FieldMetadata(alias="Contacts"),
        pydantic.Field(alias="Contacts", description="Array of objects describing the vendor's contacts."),
    ] = None
    billing_data: typing_extensions.Annotated[
        typing.Optional[VCardGetResponseAssociatedVendorBillingData],
        FieldMetadata(alias="BillingData"),
        pydantic.Field(alias="BillingData", description="Billing data for the vendor."),
    ] = None
    payment_method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentMethod"),
        pydantic.Field(alias="PaymentMethod", description="Preferred payment method for vendor."),
    ] = None
    vendor_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="VendorStatus"),
        pydantic.Field(alias="VendorStatus", description="Status of the vendor."),
    ] = None
    vendor_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="VendorId"),
        pydantic.Field(alias="VendorId", description="Unique identifier for the vendor."),
    ] = None
    enrollment_status: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="EnrollmentStatus"),
        pydantic.Field(alias="EnrollmentStatus", description="Enrollment status of the vendor."),
    ] = None
    summary: typing_extensions.Annotated[
        typing.Optional[VCardGetResponseAssociatedVendorSummary],
        FieldMetadata(alias="Summary"),
        pydantic.Field(alias="Summary", description="Summary of vendor's billing and transaction status."),
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname],
        FieldMetadata(alias="PaypointLegalname"),
        pydantic.Field(alias="PaypointLegalname", description="Legal name of the paypoint."),
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname],
        FieldMetadata(alias="PaypointDbaname"),
        pydantic.Field(alias="PaypointDbaname", description="DBA name of the paypoint."),
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="Entryname of the paypoint."),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    parent_org_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ParentOrgId"),
        pydantic.Field(alias="ParentOrgId", description="ID of the parent organization."),
    ] = None
    created_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CreatedDate"),
        pydantic.Field(alias="CreatedDate", description="Date when the vendor record was created."),
    ] = None
    last_updated: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="LastUpdated"),
        pydantic.Field(alias="LastUpdated", description="Date when the vendor's information was last updated."),
    ] = None
    remit_address_1: typing_extensions.Annotated[
        typing.Optional[Remitaddress1], FieldMetadata(alias="remitAddress1"), pydantic.Field(alias="remitAddress1")
    ] = None
    remit_address_2: typing_extensions.Annotated[
        typing.Optional[Remitaddress2], FieldMetadata(alias="remitAddress2"), pydantic.Field(alias="remitAddress2")
    ] = None
    remit_city: typing_extensions.Annotated[
        typing.Optional[Remitcity], FieldMetadata(alias="remitCity"), pydantic.Field(alias="remitCity")
    ] = None
    remit_state: typing_extensions.Annotated[
        typing.Optional[Remitstate], FieldMetadata(alias="remitState"), pydantic.Field(alias="remitState")
    ] = None
    remit_zip: typing_extensions.Annotated[
        typing.Optional[Remitzip], FieldMetadata(alias="remitZip"), pydantic.Field(alias="remitZip")
    ] = None
    remit_country: typing_extensions.Annotated[
        typing.Optional[Remitcountry], FieldMetadata(alias="remitCountry"), pydantic.Field(alias="remitCountry")
    ] = None
    payee_name_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="payeeName1"),
        pydantic.Field(alias="payeeName1", description="Primary name of the payee."),
    ] = None
    payee_name_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="payeeName2"),
        pydantic.Field(alias="payeeName2", description="Secondary name of the payee."),
    ] = None
    custom_field_1: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField1"),
        pydantic.Field(alias="customField1", description="A custom field for additional data."),
    ] = None
    custom_field_2: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customField2"),
        pydantic.Field(alias="customField2", description="Another custom field for extra data."),
    ] = None
    customer_vendor_account: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="customerVendorAccount"),
        pydantic.Field(alias="customerVendorAccount", description="Account number of paypoint in the vendor side."),
    ] = None
    internal_reference_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="InternalReferenceId"),
        pydantic.Field(alias="InternalReferenceId", description="Internal reference ID used within the system."),
    ] = None
    additional_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="additionalData"),
        pydantic.Field(alias="additionalData", description="Field for additional data, if any."),
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    stored_methods: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="StoredMethods"),
        pydantic.Field(alias="StoredMethods", description="Stored payment methods for the vendor."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .authcode import Authcode
from .avs_response import AvsResponse
from .avs_response_text import AvsResponseText
from .cvv_response import CvvResponse
from .cvv_response_text import CvvResponseText
from .emv_auth_response_data import EmvAuthResponseData
from .order_id import OrderId
from .result_code_text import ResultCodeText
from .result_codev_2 import ResultCodev2


class QueryResponseData(UniversalBaseModel):
    """
    The transaction's response data.

    Examples
    --------
    from payabli import QueryResponseData

    QueryResponseData(
        authcode="123456",
        avsresponse="N",
        avsresponse_text="No address or ZIP match only",
        cvvresponse="M",
        cvvresponse_text="CVV2/CVC2 match",
        orderid="10-bfcd5a17861d4a8690ca53c00000X",
        response="Success",
        response_code="100",
        response_code_text="Transaction was approved.",
        responsetext="SUCCESS",
        result_code="A0000",
        result_code_text="Approved",
        transactionid="8082800000",
    )
    """

    authcode: typing.Optional[Authcode] = None
    avsresponse: typing.Optional[AvsResponse] = None
    avsresponse_text: typing.Optional[AvsResponseText] = None
    cvvresponse: typing.Optional[CvvResponse] = None
    cvvresponse_text: typing.Optional[CvvResponseText] = None
    emv_auth_response_data: typing.Optional[EmvAuthResponseData] = None
    orderid: typing.Optional[OrderId] = None
    response: typing.Optional[str] = pydantic.Field(default=None)
    """
    Response text for operation: 'Success' or 'Declined'.
    """

    response_code: typing.Optional[str] = pydantic.Field(default=None)
    """
    Internal result code processing the transaction. Value 1 indicates successful operation, values 2 and 3 indicate errors.
    """

    response_code_text: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text describing the result. If resultCode = 1, will return 'Approved' or a general success message. If resultCode = 2 or 3, will contain the cause of the decline.
    """

    responsetext: typing.Optional[str] = pydantic.Field(default=None)
    """
    Text describing the result. If resultCode = 1, will return 'Approved' or a general success message. If resultCode = 2 or 3, will contain the cause of the decline.
    """

    result_code: typing_extensions.Annotated[
        typing.Optional[ResultCodev2], FieldMetadata(alias="resultCode"), pydantic.Field(alias="resultCode")
    ] = None
    result_code_text: typing_extensions.Annotated[
        typing.Optional[ResultCodeText], FieldMetadata(alias="resultCodeText"), pydantic.Field(alias="resultCodeText")
    ] = None
    transactionid: typing.Optional[str] = pydantic.Field(default=None)
    """
    The transaction identifier in Payabli.
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Type of transaction or operation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.organization_query_record import OrganizationQueryRecord
from ...types.query_summary import QuerySummary


class ListOrganizationsResponse(UniversalBaseModel):
    records: typing_extensions.Annotated[
        typing.List[OrganizationQueryRecord], FieldMetadata(alias="Records"), pydantic.Field(alias="Records")
    ]
    summary: typing_extensions.Annotated[QuerySummary, FieldMetadata(alias="Summary"), pydantic.Field(alias="Summary")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from ...types.ach_holder_type import AchHolderType
from ...types.ach_sec_code import AchSecCode
from ...types.batch_number import BatchNumber
from ...types.bill_data import BillData
from ...types.billing_fee_detail import BillingFeeDetail
from ...types.chargeback_id import ChargebackId
from ...types.datetime_nullable import DatetimeNullable
from ...types.dbaname import Dbaname
from ...types.device_id import DeviceId
from ...types.entrypage_id import EntrypageId
from ...types.external_paypoint_id import ExternalPaypointId
from ...types.external_processor_information import ExternalProcessorInformation
from ...types.fee_amount import FeeAmount
from ...types.ip_address import IpAddress
from ...types.legalname import Legalname
from ...types.netamountnullable import Netamountnullable
from ...types.operation import Operation
from ...types.order_id import OrderId
from ...types.org_parent_name import OrgParentName
from ...types.orgid import Orgid
from ...types.payor_id import PayorId
from ...types.paypoint_id import PaypointId
from ...types.pending_fee_amount import PendingFeeAmount
from ...types.query_c_fee_transaction import QueryCFeeTransaction
from ...types.query_payment_data import QueryPaymentData
from ...types.query_response_data import QueryResponseData
from ...types.query_transaction_events import QueryTransactionEvents
from ...types.query_transaction_payor_data import QueryTransactionPayorData
from ...types.refund_id import RefundId
from ...types.retrieval_id import RetrievalId
from ...types.returned_id import ReturnedId
from ...types.risk_action import RiskAction
from ...types.risk_action_code import RiskActionCode
from ...types.risk_flagged import RiskFlagged
from ...types.risk_flagged_on import RiskFlaggedOn
from ...types.risk_reason import RiskReason
from ...types.risk_status import RiskStatus
from ...types.source import Source
from ...types.split_funding import SplitFunding


class TransferDetailRecord(UniversalBaseModel):
    transfer_detail_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="transferDetailId"),
        pydantic.Field(alias="transferDetailId", description="Unique identifier for the transfer detail record"),
    ] = None
    transfer_id: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="transferId"),
        pydantic.Field(alias="transferId", description="The ID of the transfer this detail belongs to"),
    ] = None
    transaction_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="transactionId"),
        pydantic.Field(alias="transactionId", description="The transaction ID in Payabli's system"),
    ] = None
    transaction_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="transactionNumber"),
        pydantic.Field(alias="transactionNumber", description="External transaction reference number"),
    ] = None
    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    The transaction type (credit or debit)
    """

    category: typing.Optional[str] = pydantic.Field(default=None)
    """
    A field used to categorize the transaction details. Values include: auth, decline, refund, adj, cb, split
    """

    gross_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="grossAmount"),
        pydantic.Field(alias="grossAmount", description="The gross amount of the transaction"),
    ] = None
    charge_back_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="chargeBackAmount"),
        pydantic.Field(alias="chargeBackAmount", description="Chargeback amount deducted from transaction"),
    ] = None
    returned_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="returnedAmount"),
        pydantic.Field(alias="returnedAmount", description="ACH return amount deducted from transaction"),
    ] = None
    refund_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="refundAmount"),
        pydantic.Field(alias="refundAmount", description="Refund amount deducted from transaction"),
    ] = None
    hold_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="holdAmount"),
        pydantic.Field(alias="holdAmount", description="Amount being held for fraud or risk concerns"),
    ] = None
    released_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="releasedAmount"),
        pydantic.Field(
            alias="releasedAmount", description="Previously held funds that have been released after a risk review"
        ),
    ] = None
    billing_fees_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="billingFeesAmount"),
        pydantic.Field(alias="billingFeesAmount", description="Charges applied for transactions and services"),
    ] = None
    third_party_paid_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="thirdPartyPaidAmount"),
        pydantic.Field(
            alias="thirdPartyPaidAmount",
            description="Payments captured in the batch cycle that are deposited separately. For example,  checks or cash payments recorded in the batch but not deposited via Payabli,  or card brands making a direct transfer in certain situations.",
        ),
    ] = None
    adjustments_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="adjustmentsAmount"),
        pydantic.Field(alias="adjustmentsAmount", description="Corrections applied to Billing & Fees charges"),
    ] = None
    net_transfer_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="netTransferAmount"),
        pydantic.Field(alias="netTransferAmount", description="The net amount after all deductions"),
    ] = None
    split_funding_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="splitFundingAmount"),
        pydantic.Field(alias="splitFundingAmount", description="Total amount directed to split funding destinations"),
    ] = None
    billing_fees_details: typing_extensions.Annotated[
        typing.Optional[typing.List[BillingFeeDetail]],
        FieldMetadata(alias="billingFeesDetails"),
        pydantic.Field(alias="billingFeesDetails"),
    ] = None
    parent_org_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="ParentOrgName"), pydantic.Field(alias="ParentOrgName")
    ] = None
    paypoint_dbaname: typing_extensions.Annotated[
        typing.Optional[Dbaname], FieldMetadata(alias="PaypointDbaname"), pydantic.Field(alias="PaypointDbaname")
    ] = None
    paypoint_legalname: typing_extensions.Annotated[
        typing.Optional[Legalname], FieldMetadata(alias="PaypointLegalname"), pydantic.Field(alias="PaypointLegalname")
    ] = None
    paypoint_entryname: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaypointEntryname"),
        pydantic.Field(alias="PaypointEntryname", description="The paypoint's entryname"),
    ] = None
    payment_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="PaymentTransId"),
        pydantic.Field(alias="PaymentTransId", description="The transaction ID for the payment"),
    ] = None
    connector_name: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="ConnectorName"),
        pydantic.Field(alias="ConnectorName", description="The payment connector used to process the transaction"),
    ] = None
    external_processor_information: typing_extensions.Annotated[
        typing.Optional[ExternalProcessorInformation],
        FieldMetadata(alias="ExternalProcessorInformation"),
        pydantic.Field(alias="ExternalProcessorInformation"),
    ] = None
    gateway_trans_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="GatewayTransId"),
        pydantic.Field(alias="GatewayTransId", description="Internal identifier used for processing"),
    ] = None
    order_id: typing_extensions.Annotated[
        typing.Optional[OrderId], FieldMetadata(alias="OrderId"), pydantic.Field(alias="OrderId")
    ] = None
    method: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="Method"),
        pydantic.Field(alias="Method", description="Payment method used: card, ach, or wallet"),
    ] = None
    batch_number: typing_extensions.Annotated[
        typing.Optional[BatchNumber], FieldMetadata(alias="BatchNumber"), pydantic.Field(alias="BatchNumber")
    ] = None
    batch_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="BatchAmount"),
        pydantic.Field(alias="BatchAmount", description="The amount of the batch"),
    ] = None
    payor_id: typing_extensions.Annotated[
        typing.Optional[PayorId],
        FieldMetadata(alias="PayorId"),
        pydantic.Field(alias="PayorId", description="Unique ID for customer linked to the transaction"),
    ] = None
    payment_data: typing_extensions.Annotated[
        typing.Optional[QueryPaymentData], FieldMetadata(alias="PaymentData"), pydantic.Field(alias="PaymentData")
    ] = None
    trans_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="TransStatus"),
        pydantic.Field(
            alias="TransStatus",
            description="Status of transaction. See [the\ndocs](/developers/references/money-in-statuses#money-in-transaction-status) for a\nfull reference.",
        ),
    ] = None
    paypoint_id: typing_extensions.Annotated[
        typing.Optional[PaypointId], FieldMetadata(alias="PaypointId"), pydantic.Field(alias="PaypointId")
    ] = None
    total_amount: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="TotalAmount"),
        pydantic.Field(
            alias="TotalAmount", description="Transaction total amount (including service fee or sub-charge)"
        ),
    ] = None
    net_amount: typing_extensions.Annotated[
        typing.Optional[Netamountnullable],
        FieldMetadata(alias="NetAmount"),
        pydantic.Field(alias="NetAmount", description="Net amount paid"),
    ] = None
    fee_amount: typing_extensions.Annotated[
        typing.Optional[FeeAmount], FieldMetadata(alias="FeeAmount"), pydantic.Field(alias="FeeAmount")
    ] = None
    settlement_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="SettlementStatus"),
        pydantic.Field(
            alias="SettlementStatus",
            description="Settlement status for transaction. See [the docs](/developers/references/money-in-statuses#payment-funding-status) for a full reference.",
        ),
    ] = None
    operation: typing_extensions.Annotated[
        typing.Optional[Operation], FieldMetadata(alias="Operation"), pydantic.Field(alias="Operation")
    ] = None
    response_data: typing_extensions.Annotated[
        typing.Optional[QueryResponseData], FieldMetadata(alias="ResponseData"), pydantic.Field(alias="ResponseData")
    ] = None
    source: typing_extensions.Annotated[
        typing.Optional[Source], FieldMetadata(alias="Source"), pydantic.Field(alias="Source")
    ] = None
    schedule_reference: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="ScheduleReference"),
        pydantic.Field(
            alias="ScheduleReference",
            description="Reference to the subscription or schedule that originated the transaction",
        ),
    ] = None
    org_id: typing_extensions.Annotated[
        typing.Optional[Orgid], FieldMetadata(alias="OrgId"), pydantic.Field(alias="OrgId")
    ] = None
    refund_id: typing_extensions.Annotated[
        typing.Optional[RefundId], FieldMetadata(alias="RefundId"), pydantic.Field(alias="RefundId")
    ] = None
    returned_id: typing_extensions.Annotated[
        typing.Optional[ReturnedId], FieldMetadata(alias="ReturnedId"), pydantic.Field(alias="ReturnedId")
    ] = None
    chargeback_id: typing_extensions.Annotated[
        typing.Optional[ChargebackId], FieldMetadata(alias="ChargebackId"), pydantic.Field(alias="ChargebackId")
    ] = None
    retrieval_id: typing_extensions.Annotated[
        typing.Optional[RetrievalId], FieldMetadata(alias="RetrievalId"), pydantic.Field(alias="RetrievalId")
    ] = None
    trans_additional_data: typing_extensions.Annotated[
        typing.Optional[typing.Any],
        FieldMetadata(alias="TransAdditionalData"),
        pydantic.Field(alias="TransAdditionalData", description="Additional transaction data"),
    ] = None
    invoice_data: typing_extensions.Annotated[
        typing.Optional[BillData],
        FieldMetadata(alias="invoiceData"),
        pydantic.Field(alias="invoiceData", description="Associated invoice data"),
    ] = None
    entrypage_id: typing_extensions.Annotated[
        typing.Optional[EntrypageId], FieldMetadata(alias="EntrypageId"), pydantic.Field(alias="EntrypageId")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId],
        FieldMetadata(alias="externalPaypointID"),
        pydantic.Field(alias="externalPaypointID"),
    ] = None
    is_validated_ach: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="IsValidatedACH"),
        pydantic.Field(alias="IsValidatedACH", description="Indicates whether the ACH account has been validated"),
    ] = None
    transaction_time: typing_extensions.Annotated[
        typing.Optional[DatetimeNullable],
        FieldMetadata(alias="TransactionTime"),
        pydantic.Field(alias="TransactionTime", description="Transaction date and time, in UTC"),
    ] = None
    customer: typing_extensions.Annotated[
        typing.Optional[QueryTransactionPayorData], FieldMetadata(alias="Customer"), pydantic.Field(alias="Customer")
    ] = None
    split_funding_instructions: typing_extensions.Annotated[
        typing.Optional[SplitFunding],
        FieldMetadata(alias="splitFundingInstructions"),
        pydantic.Field(alias="splitFundingInstructions"),
    ] = None
    cfee_transactions: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryCFeeTransaction]],
        FieldMetadata(alias="CfeeTransactions"),
        pydantic.Field(alias="CfeeTransactions"),
    ] = None
    transaction_events: typing_extensions.Annotated[
        typing.Optional[typing.List[QueryTransactionEvents]],
        FieldMetadata(alias="TransactionEvents"),
        pydantic.Field(alias="TransactionEvents"),
    ] = None
    pending_fee_amount: typing_extensions.Annotated[
        typing.Optional[PendingFeeAmount],
        FieldMetadata(alias="PendingFeeAmount"),
        pydantic.Field(alias="PendingFeeAmount"),
    ] = None
    risk_flagged: typing_extensions.Annotated[
        typing.Optional[RiskFlagged], FieldMetadata(alias="RiskFlagged"), pydantic.Field(alias="RiskFlagged")
    ] = None
    risk_flagged_on: typing_extensions.Annotated[
        typing.Optional[RiskFlaggedOn], FieldMetadata(alias="RiskFlaggedOn"), pydantic.Field(alias="RiskFlaggedOn")
    ] = None
    risk_status: typing_extensions.Annotated[
        typing.Optional[RiskStatus], FieldMetadata(alias="RiskStatus"), pydantic.Field(alias="RiskStatus")
    ] = None
    risk_reason: typing_extensions.Annotated[
        typing.Optional[RiskReason], FieldMetadata(alias="RiskReason"), pydantic.Field(alias="RiskReason")
    ] = None
    risk_action: typing_extensions.Annotated[
        typing.Optional[RiskAction], FieldMetadata(alias="RiskAction"), pydantic.Field(alias="RiskAction")
    ] = None
    risk_action_code: typing_extensions.Annotated[
        typing.Optional[RiskActionCode], FieldMetadata(alias="RiskActionCode"), pydantic.Field(alias="RiskActionCode")
    ] = None
    device_id: typing_extensions.Annotated[
        typing.Optional[DeviceId], FieldMetadata(alias="DeviceId"), pydantic.Field(alias="DeviceId")
    ] = None
    ach_sec_code: typing_extensions.Annotated[
        typing.Optional[AchSecCode], FieldMetadata(alias="AchSecCode"), pydantic.Field(alias="AchSecCode")
    ] = None
    ach_holder_type: typing_extensions.Annotated[
        typing.Optional[AchHolderType], FieldMetadata(alias="AchHolderType"), pydantic.Field(alias="AchHolderType")
    ] = None
    ip_address: typing_extensions.Annotated[
        typing.Optional[IpAddress], FieldMetadata(alias="IpAddress"), pydantic.Field(alias="IpAddress")
    ] = None
    is_same_day_ach: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="IsSameDayACH"),
        pydantic.Field(alias="IsSameDayACH", description="Indicates if this was a same-day ACH transaction."),
    ] = None
    wallet_type: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="WalletType"),
        pydantic.Field(alias="WalletType", description="Type of wallet used for the transaction (if applicable)"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .created_at import CreatedAt


class ApplicationDetailsRecordMessagesItem(UniversalBaseModel):
    content: typing.Optional[str] = None
    created_at: typing_extensions.Annotated[
        typing.Optional[CreatedAt], FieldMetadata(alias="createdAt"), pydantic.Field(alias="createdAt")
    ] = None
    current_application_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="currentApplicationStatus"),
        pydantic.Field(alias="currentApplicationStatus"),
    ] = None
    current_application_sub_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="currentApplicationSubStatus"),
        pydantic.Field(alias="currentApplicationSubStatus"),
    ] = None
    id: typing.Optional[int] = None
    message_type: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="messageType"), pydantic.Field(alias="messageType")
    ] = None
    original_application_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="originalApplicationStatus"),
        pydantic.Field(alias="originalApplicationStatus"),
    ] = None
    original_application_sub_status: typing_extensions.Annotated[
        typing.Optional[int],
        FieldMetadata(alias="originalApplicationSubStatus"),
        pydantic.Field(alias="originalApplicationSubStatus"),
    ] = None
    room_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="roomId"), pydantic.Field(alias="roomId")
    ] = None
    user_id: typing_extensions.Annotated[
        typing.Optional[int], FieldMetadata(alias="userId"), pydantic.Field(alias="userId")
    ] = None
    user_name: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="userName"), pydantic.Field(alias="userName")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class TransferOutDetailCheckData(UniversalBaseModel):
    """
    Check data for an outbound transfer detail.
    """

    check_number: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CheckNumber"),
        pydantic.Field(alias="CheckNumber", description="The check number."),
    ] = None
    check_data: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="CheckData"),
        pydantic.Field(alias="CheckData", description="Additional check data."),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
